#!/usr/bin/perl -w

use Test::More 'no_plan';

package Catch;

sub TIEHANDLE {
    my($class, $var) = @_;
    return bless { var => $var }, $class;
}

sub PRINT  {
    my($self) = shift;
    ${'main::'.$self->{var}} .= join '', @_;
}

sub OPEN  {}    # XXX Hackery in case the user redirects
sub CLOSE {}    # XXX STDERR/STDOUT.  This is not the behavior we want.

sub READ {}
sub READLINE {}
sub GETC {}
sub BINMODE {}

my $Original_File = 'root/usr/lib/perl5/site_perl/esmith/FormMagick.pm';

package main;

# pre-5.8.0's warns aren't caught by a tied STDERR.
$SIG{__WARN__} = sub { $main::_STDERR_ .= join '', @_; };
tie *STDOUT, 'Catch', '_STDOUT_' or die $!;
tie *STDERR, 'Catch', '_STDERR_' or die $!;

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 164 root/usr/lib/perl5/site_perl/esmith/FormMagick.pm

my $out = `$^X -cw $Original_File 2>&1`;
is( $?, 0, 'compiles' );
is( $out, "$Original_File syntax OK\n", 'no warnings' );

use_ok('CGI::FormMagick');
use_ok('esmith::FormMagick');
use vars qw($fm);

$ENV{ESMITH_LEXPATH} = "20e-smith-formmagick/locale";
ok(open (DATA, "20e-smith-formmagick/data.xml"), "opened data file for input");
ok(esmith::FormMagick->can('new'), "We can call new");
ok($fm = esmith::FormMagick->new(more_lexicons => [ 'test' ]), "create e::fm object");
isa_ok($fm, 'esmith::FormMagick');
is($ENV{PATH}, '/bin:/usr/bin:/usr/local/bin', 'Set $ENV{PATH}');
is($CGI::POST_MAX, 1024 * 100, "Set CGI::POST_MAX");
is($CGI::DISABLE_UPLOADS, 1, "Set CGI::DISABLE_UPLOADS");
is($<, $>, "Set real to effective UID");
is($(, $), "Set real to effective UID");

$ENV{HTTP_ACCEPT_LANGUAGE} = "fr";
$fm->parse_xml(); # suck in lexicons without displaying
is($fm->localise("YES"), "Oui", "Localisation works");
is($fm->localise("TEST"), "Essayer", "more_lexicons works");

# warning avoidance; better ways to do this gratefully accepted
my ($foo, $bar) = ($CGI::POST_MAX, $CGI::DISABLE_UPLOADS); 
close DATA;


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 327 root/usr/lib/perl5/site_perl/esmith/FormMagick.pm
is(_filename(filename => 'foo'), 'foo', "Pick up filename from args");
is(_filename(), $0, "Pick up filename from \$0");

    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 345 root/usr/lib/perl5/site_perl/esmith/FormMagick.pm
# bloody hard to test anywhere other than on a server; not sure how to
# do it.  -- Skud
can_ok('main', '_scriptname_from_filename');

    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 371 root/usr/lib/perl5/site_perl/esmith/FormMagick.pm

$ENV{ESMITH_LEXPATH} = "20e-smith-formmagick/locale";
my @expected_lexfiles = qw(
    20e-smith-formmagick/locale/en/FormMagick/general
    20e-smith-formmagick/locale/fr/FormMagick/general
    20e-smith-formmagick/locale/en/test
    20e-smith-formmagick/locale/fr/test
);

my @lexfiles = _lexicon_filename_list(more_lexicons => [ 'test' ]);
is_deeply(\@expected_lexfiles, \@lexfiles, "Found the right localisation lexicons");


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 437 root/usr/lib/perl5/site_perl/esmith/FormMagick.pm
can_ok('main', '_read_lexicons');
like(_read_lexicons('20e-smith-formmagick/locale/fr/test'), qr'Essayer', "_read_lexicons");

    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 465 root/usr/lib/perl5/site_perl/esmith/FormMagick.pm
my $nav = esmith::FormMagick->new(filename=>"20e-smith-formmagick/navigation");
can_ok($nav, '_navigation_setup');
$nav->_navigation_setup(filename=>"20e-smith-formmagick/navigation");
is($nav->heading, 'Test heading', "Picked up navigation heading");

    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 507 root/usr/lib/perl5/site_perl/esmith/FormMagick.pm
my $fm = esmith::FormMagick->new(filename=>"20e-smith-formmagick/nopipes");
can_ok($fm, "get_validation_attribute");
is($fm->get_validation_attribute({validation => "foo"}), "foo, nopipes", "nopipes added to existing validation");
is($fm->get_validation_attribute({validation => undef}), "nopipes", "nopipes added to empty validation");

#$fm->parse_xml();
my $badcgi  = CGI->new( { testfield => '|' } );
$fm->{cgi} = $badcgi;

my $field = {
    validation =>  '',
    id          => 'testfield',
    label       => 'Test Field',
};

isnt(grep(/PIPE/,$fm->validate_field($field)), undef, "Test a field with a pipe in it");
isnt($fm->validate_field($field), "OK", "Test a field with a pipe in it");


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 554 root/usr/lib/perl5/site_perl/esmith/FormMagick.pm
my $test = {a => "b", c => "d"};
is($fm->props_to_query_string($test), "a=b;c=d", "props_to_query_string");

    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 576 root/usr/lib/perl5/site_perl/esmith/FormMagick.pm
my $fm = esmith::FormMagick->new();
turn_off_buttons($fm);
foreach (qw(nextbutton previousbutton finishbutton resetbutton startoverlink)) {
    is($fm->$_, 0, "turn_off_buttons turns off $_");
}

    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 614 root/usr/lib/perl5/site_perl/esmith/FormMagick.pm
my $fm = esmith::FormMagick->new();
$fm->{cgi} = CGI->new("");
can_ok('main', 'set_status_message');
set_status_message($fm, "Testing");
is($fm->{cgi}->param("status_message"), "Testing", "Set status message");

    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 635 root/usr/lib/perl5/site_perl/esmith/FormMagick.pm
my $fm = esmith::FormMagick->new();
$fm->{cgi} = CGI->new("");
set_status_message($fm, "test status message");
$fm->nextbutton(1);
print_status_message($fm);
like($_STDOUT_, qr/test status message/, "Saw status message");
is($fm->{cgi}->param("status_message"), "", "Reset status message to blank after printing");
is($fm->nextbutton(), 0, "turn off buttons after status message");

    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 698 root/usr/lib/perl5/site_perl/esmith/FormMagick.pm
my $fm = esmith::FormMagick->new(filename=>"20e-smith-formmagick/navigation");
is($fm->description, "Test description", "Read description header");

    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 719 root/usr/lib/perl5/site_perl/esmith/FormMagick.pm
my $fm = esmith::FormMagick->new(filename=>"20e-smith-formmagick/navigation");
is($fm->heading, "Test heading", "Read heading header");

    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 742 root/usr/lib/perl5/site_perl/esmith/FormMagick.pm
my $fm = esmith::FormMagick->new(filename=>"20e-smith-formmagick/navigation");
is($fm->description_weight, 1200, "Read description weight");

    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 759 root/usr/lib/perl5/site_perl/esmith/FormMagick.pm
my $fm = esmith::FormMagick->new(filename=>"20e-smith-formmagick/navigation");
is($fm->heading_weight, 1000, "Read heading weight");

    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 780 root/usr/lib/perl5/site_perl/esmith/FormMagick.pm
my $fm = esmith::FormMagick->new();
isnt($fm->validate_password('strong','f00'),'OK','validate_password strong');
is($fm->validate_password('strong','f%nn*f2@'),'OK',' ..using strong password');
isnt($fm->validate_password('normal','f00'),'OK','validate_password normal');
is($fm->validate_password('normal','f%00B4r'),'OK',' ..using normal password');
is($fm->validate_password('none','f00'),'OK','validate_password none');

    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 849 root/usr/lib/perl5/site_perl/esmith/FormMagick.pm
can_ok('main', 'nopipes');
is(nopipes(undef, 'nopipes in this string!'),'OK','nopipes in this string!');
like(nopipes(undef, 'has|pipe'),qr/NO_PIPES/,' .. no pipes allowed');

    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 872 root/usr/lib/perl5/site_perl/esmith/FormMagick.pm
can_ok('main', 'gen_locale_date_string');

    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

